==> kdegraphics_3.2.2.orig.tar.gz: kdegraphics-3.2.2/ksvg/dom/SVGAnimatedRect.cc <==
/*
    Copyright (C) 2001-2003 KSVG Team
    This file is part of the KDE project

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/

#include "SVGAnimatedRect.h"
#include "SVGAnimatedRectImpl.h"
#include "SVGRect.h"

using namespace KSVG;

SVGAnimatedRect::SVGAnimatedRect()
{
	impl = new SVGAnimatedRectImpl();
	impl->ref();
}

SVGAnimatedRect::SVGAnimatedRect(const SVGAnimatedRect &other) : impl(0)
{
	(*this) = other;
}

SVGAnimatedRect &SVGAnimatedRect::operator=(const SVGAnimatedRect &other)
{
	if(impl == other.impl)
		return *this;

	if(impl)
		impl->deref();

	impl = other.impl;

	if(impl)
		impl->ref();

	return *this;
}

SVGAnimatedRect::SVGAnimatedRect(SVGAnimatedRectImpl *other)
{
	impl = other;
	if(impl)
		impl->ref();
}

SVGAnimatedRect::~SVGAnimatedRect()
{
	if(impl)
		impl->deref();
}

SVGRect SVGAnimatedRect::baseVal() const
{
	if(!impl) return SVGRect(0);
	return SVGRect(impl->baseVal());
}

SVGRect SVGAnimatedRect::animVal() const
{
	if(!impl) return SVGRect(0);
	return SVGRect(impl->animVal());
}

// vim:ts=4:noet

==> kdegraphics_3.5.2.orig.tar.gz: kdegraphics-3.5.2/ksvg/dom/SVGAnimatedRect.cc <==
/*
    Copyright (C) 2001-2003 KSVG Team
    This file is part of the KDE project

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#include "SVGAnimatedRect.h"
#include "SVGAnimatedRectImpl.h"
#include "SVGRect.h"

using namespace KSVG;

SVGAnimatedRect::SVGAnimatedRect()
{
	impl = new SVGAnimatedRectImpl();
	impl->ref();
}

SVGAnimatedRect::SVGAnimatedRect(const SVGAnimatedRect &other) : impl(0)
{
	(*this) = other;
}

SVGAnimatedRect &SVGAnimatedRect::operator=(const SVGAnimatedRect &other)
{
	if(impl == other.impl)
		return *this;

	if(impl)
		impl->deref();

	impl = other.impl;

	if(impl)
		impl->ref();

	return *this;
}

SVGAnimatedRect::SVGAnimatedRect(SVGAnimatedRectImpl *other)
{
	impl = other;
	if(impl)
		impl->ref();
}

SVGAnimatedRect::~SVGAnimatedRect()
{
	if(impl)
		impl->deref();
}

SVGRect SVGAnimatedRect::baseVal() const
{
	if(!impl) return SVGRect(0);
	return SVGRect(impl->baseVal());
}

SVGRect SVGAnimatedRect::animVal() const
{
	if(!impl) return SVGRect(0);
	return SVGRect(impl->animVal());
}

// vim:ts=4:noet
